summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp b/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
index bd022e148..90a2afdc3 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
@@ -1842,7 +1842,7 @@ void TQVariant::Private::clear()
A TQVariant object holds a single value of a single type() at a
time. (Some type()s are multi-valued, for example a string list.)
- You can tqfind out what type, T, the variant holds, convert it to a
+ You can find out what type, T, the variant holds, convert it to a
different type using one of the asT() functions, e.g. asSize(),
get its value using one of the toT() functions, e.g. toSize(), and
check whether the type can be converted to a particular type using
@@ -1870,11 +1870,11 @@ void TQVariant::Private::clear()
\code
TQDataStream out(...);
- TQVariant v(123); // The variant now tqcontains an int
+ TQVariant v(123); // The variant now contains an int
int x = v.toInt(); // x = 123
out << v; // Writes a type tag and an int to out
- v = TQVariant("hello"); // The variant now tqcontains a TQCString
- v = TQVariant(tr("hello"));// The variant now tqcontains a TQString
+ v = TQVariant("hello"); // The variant now contains a TQCString
+ v = TQVariant(tr("hello"));// The variant now contains a TQString
int y = v.toInt(); // y = 0 since v cannot be converted to an int
TQString s = v.toString(); // s = tr("hello") (see TQObject::tr())
out << v; // Writes a type tag and a TQString to out
@@ -4427,7 +4427,7 @@ TQMap<TQString, TQVariant>& TQVariant::asMap()
\row \i Int \i String, CString, ByteArray, Double, Bool, UInt, LongLong, ULongLong, KeySequence
\row \i LongLong \i String, CString, ByteArray, Double, Bool, UInt, LongLong, ULongLong, KeySequence
\row \i ULongLong \i String, CString, ByteArray, Double, Bool, UInt, LongLong, ULongLong, KeySequence
- \row \i List \i StringList (if the list tqcontains only strings or
+ \row \i List \i StringList (if the list contains only strings or
something that can be cast to a string)
\row \i String \i CString, ByteArray, CString, Int, UInt, Bool, Double, Date,
Time, DateTime, KeySequence, Font, Color